import { Args } from '@oclif/core';
import { ApifyCommand } from '../../lib/apify_command.js';
import { error, info } from '../../lib/outputs.js';
import { getLoggedClientOrThrow, outputJobLog } from '../../lib/utils.js';
export class RunsLogCommand extends ApifyCommand {
    async run() {
        const { runId } = this.args;
        const apifyClient = await getLoggedClientOrThrow();
        const run = await apifyClient.run(runId).get();
        if (!run) {
            error({ message: `Run with ID "${runId}" was not found on your account.` });
            return;
        }
        info({ message: `Log for run with ID "${runId}":\n` });
        try {
            await outputJobLog(run);
        }
        catch (err) {
            // This should never happen...
            error({ message: `Failed to get log for run with ID "${runId}": ${err.message}` });
        }
    }
}
Object.defineProperty(RunsLogCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: 'Prints the log of a specific run.'
});
Object.defineProperty(RunsLogCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        runId: Args.string({
            required: true,
            description: 'The run ID to get the log from.',
        }),
    }
});
//# sourceMappingURL=log.js.map