import { ACTOR_JOB_STATUSES } from '@apify/consts';
import { Args } from '@oclif/core';
import { ApifyCommand } from '../../lib/apify_command.js';
import { error, success } from '../../lib/outputs.js';
import { getLoggedClientOrThrow } from '../../lib/utils.js';
const resurrectStatuses = [
    ACTOR_JOB_STATUSES.SUCCEEDED,
    ACTOR_JOB_STATUSES.FAILED,
    ACTOR_JOB_STATUSES.ABORTED,
    ACTOR_JOB_STATUSES.TIMED_OUT,
];
export class RunsResurrectCommand extends ApifyCommand {
    async run() {
        const { runId } = this.args;
        const apifyClient = await getLoggedClientOrThrow();
        const run = await apifyClient.run(runId).get();
        if (!run) {
            error({ message: `Run with ID "${runId}" was not found on your account.` });
            return;
        }
        if (!resurrectStatuses.includes(run.status)) {
            error({
                message: `Run with ID "${runId}" cannot be resurrected, as it is still running or in the process of aborting.`,
            });
            return;
        }
        try {
            const result = await apifyClient.run(runId).resurrect();
            if (this.flags.json) {
                return result;
            }
            success({ message: `Run with ID "${runId}" was resurrected successfully.` });
        }
        catch (err) {
            const casted = err;
            error({
                message: `Failed to resurrect run "${runId}".\n  ${casted.message || casted}`,
            });
        }
        return undefined;
    }
}
Object.defineProperty(RunsResurrectCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: 'Resurrects an aborted or finished Actor Run.'
});
Object.defineProperty(RunsResurrectCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        runId: Args.string({
            required: true,
            description: 'The run ID to resurrect.',
        }),
    }
});
Object.defineProperty(RunsResurrectCommand, "enableJsonFlag", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: true
});
//# sourceMappingURL=resurrect.js.map